==> haskell-regex-applicative-0.3.4-256-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-applicative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-applicative
version:              0.3.4
visibility:           public
id:                   regex-applicative-0.3.4-IXUa5E4aM1Y2olN03bouzQ
key:                  regex-applicative-0.3.4-IXUa5E4aM1Y2olN03bouzQ
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka
homepage:             https://github.com/feuerbach/regex-applicative
synopsis:             Regex-based parsing with applicative interface
description:
    regex-applicative is a Haskell library for parsing using regular expressions.
    Parsers can be built using Applicative interface.

category:             Text
abi:                  e50533be299656bdb0e844ab0cf5c53a
exposed:              True
exposed-modules:
    Text.Regex.Applicative Text.Regex.Applicative.Common
    Text.Regex.Applicative.Object Text.Regex.Applicative.Reference
    Text.Regex.Applicative.StateQueue

hidden-modules:
    Text.Regex.Applicative.Interface Text.Regex.Applicative.Types
    Text.Regex.Applicative.Compile

import-dirs:          /usr/lib/ghc-9.4.8/site-local/regex-applicative-0.3.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/regex-applicative-0.3.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/regex-applicative-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-applicative
hs-libraries:         HSregex-applicative-0.3.4-IXUa5E4aM1Y2olN03bouzQ
depends:
    base-4.17.2.1 containers-0.6.7
    filtrable-0.1.6.0-ajei2zSp0K77WA93OCopG transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-regex-applicative/html/regex-applicative.haddock

haddock-html:         /usr/share/doc/haskell-regex-applicative/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-regex-applicative-0.3.4-257-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-regex-applicative.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 regex-applicative
version:              0.3.4
visibility:           public
id:                   regex-applicative-0.3.4-L0hLivuuEKJ1432NTPHu1d
key:                  regex-applicative-0.3.4-L0hLivuuEKJ1432NTPHu1d
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka
homepage:             https://github.com/feuerbach/regex-applicative
synopsis:             Regex-based parsing with applicative interface
description:
    regex-applicative is a Haskell library for parsing using regular expressions.
    Parsers can be built using Applicative interface.

category:             Text
abi:                  d9d1cdf48a0478f562adb83e2ccbc9e9
exposed:              True
exposed-modules:
    Text.Regex.Applicative Text.Regex.Applicative.Common
    Text.Regex.Applicative.Object Text.Regex.Applicative.Reference
    Text.Regex.Applicative.StateQueue

hidden-modules:
    Text.Regex.Applicative.Interface Text.Regex.Applicative.Types
    Text.Regex.Applicative.Compile

import-dirs:          /usr/lib/ghc-9.4.8/site-local/regex-applicative-0.3.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/regex-applicative-0.3.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/regex-applicative-0.3.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-regex-applicative
hs-libraries:         HSregex-applicative-0.3.4-L0hLivuuEKJ1432NTPHu1d
depends:
    base-4.17.2.1 containers-0.6.7
    filtrable-0.1.6.0-C4M6vt2ruj9LEqarwdVyLq transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-regex-applicative/html/regex-applicative.haddock

haddock-html:         /usr/share/doc/haskell-regex-applicative/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
